Code for defining and compiling 'consequence' functions, ie, functions from a
binding map generated by a [pattern.match] to some successful
transformation (or a failure!).
See pattern.rule for a detailed treatment.
Code for defining and compiling 'consequence' functions, ie, functions from a binding map generated by a [[[pattern.match]]] to some successful transformation (or a failure!). See [[pattern.rule]] for a detailed treatment.
Implementation of a pattern matching system inspired by Gerald Jay Sussman's
lecture notes for MIT
6.945.
See pattern.rule for a higher-level API.
pattern.match and pattern.rule are spiritually similar to Alexey
Radul's Rules library for Scheme, and the
pattern matching system described in GJS and Hanson's Software Design for
Flexibility.
Implementation of a pattern matching system inspired by [Gerald Jay Sussman's lecture notes for MIT 6.945](http://groups.csail.mit.edu/mac/users/gjs/6.945/). See [[pattern.rule]] for a higher-level API. [[pattern.match]] and [[pattern.rule]] are spiritually similar to Alexey Radul's [Rules](https://github.com/axch/rules) library for Scheme, and the pattern matching system described in GJS and Hanson's [Software Design for Flexibility](https://mitpress.mit.edu/books/software-design-flexibility).
This namespace provides an API for building rules out of the matchers and
matcher combinators declared in pattern.match, along with a series of
combinators for building advanced term-rewriting systems.
This namespace provides an API for building rules out of the matchers and matcher combinators declared in [[pattern.match]], along with a series of combinators for building advanced term-rewriting systems.
The syntax namespace defines the default syntax for patterns corresponding to
the matcher combinators defined in pattern.match.
The syntax namespace defines the default syntax for patterns corresponding to the matcher combinators defined in [[pattern.match]].
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |